@@ -18,12 +18,13 @@ from weave.trace.op_protocol import Op
 from weave.trace.vals import WeaveObject
 from weave.trace.weave_client import sanitize_object_name
 
-try:
-    import numpy as np
-except ImportError:
-    _NUMPY_AVAILABLE = False
-else:
-    _NUMPY_AVAILABLE = True
+
+def _import_numpy() -> Optional[Any]:
+    try:
+        import numpy
+    except ImportError:
+        return None
+    return numpy
 
 
 class Scorer(Object):
@@ -79,8 +80,7 @@ def _validate_scorer_signature(scorer: Union[Callable, Op, Scorer]) -> bool:
 
 
 def variance(data: Sequence[Union[int, float]]) -> float:
-    """
-    Calculate the variance of a sequence of numeric values.
+    """Calculate the variance of a sequence of numeric values.
 
     Args:
         data (Sequence[Union[int, float]]): A sequence of numeric values.
@@ -104,8 +104,7 @@ def variance(data: Sequence[Union[int, float]]) -> float:
 
 
 def stderr(data: Sequence[Union[int, float]]) -> float:
-    """
-    Calculate the standard error of the mean for a sequence of numeric values.
+    """Calculate the standard error of the mean for a sequence of numeric values.
 
     Args:
         data (Sequence[Union[int, float]]): A sequence of numeric values.
@@ -124,7 +123,7 @@ def stderr(data: Sequence[Union[int, float]]) -> float:
     if len(data) <= 1:
         return 0
 
-    if _NUMPY_AVAILABLE:
+    if np := _import_numpy():
         sample_variance = float(np.var(data, ddof=1))
         return float(np.sqrt(sample_variance / len(data)))
     else:
@@ -160,7 +159,7 @@ def auto_summarize(data: list) -> Optional[dict[str, Any]]:
             "true_fraction": true_count / len(data),
         }
     elif isinstance(val, Number):
-        if _NUMPY_AVAILABLE:
+        if np := _import_numpy():
             return {"mean": np.mean(data).item()}
         else:
             return {"mean": sum(data) / len(data)}
