@@ -1,20 +1,14 @@
 """Alternate boxing implementation for Weave Trace.
 
 This copies many things from query service's box.py, but it notably
-does not box None and bool which simplify checks for trace users."""
+does not box None and bool which simplify checks for trace users.
+"""
 
 from __future__ import annotations
 
 import datetime
 from typing import Any, TypeVar
 
-try:
-    from numpy import array, asarray, ndarray
-except ImportError:
-    _NUMPY_AVAILABLE = False
-else:
-    _NUMPY_AVAILABLE = True
-
 from weave.trace.refs import Ref
 
 T = TypeVar("T")
@@ -55,35 +49,10 @@ class BoxedTimedelta(datetime.timedelta):
         )
 
 
-# See https://numpy.org/doc/stable/user/basics.subclassing.html
-if _NUMPY_AVAILABLE:
-
-    class BoxedNDArray(ndarray):  # pyright: ignore[reportRedeclaration]
-        ref: Ref | None = None
-
-        def __new__(cls, input_array: Any) -> BoxedNDArray:
-            obj = asarray(input_array).view(cls)
-            return obj
-
-        def __array_finalize__(self, obj: Any) -> None:
-            if obj is None:
-                return
-else:
-    # Define a placeholder class when numpy is not available
-    class BoxedNDArray:  # type: ignore[no-redef]
-        ref: Ref | None = None
-
-        def __init__(self, *args: Any, **kwargs: Any) -> None:
-            raise ImportError("numpy is required for BoxedNDArray but is not installed")
-
-
 def box(
     obj: T,
-) -> (
-    T | BoxedInt | BoxedFloat | BoxedStr | BoxedNDArray | BoxedDatetime | BoxedTimedelta
-):
-    """
-    Box an object to add reference tracking capabilities.
+) -> T | BoxedInt | BoxedFloat | BoxedStr | BoxedDatetime | BoxedTimedelta:
+    """Box an object to add reference tracking capabilities.
 
     Args:
         obj: The object to box.
@@ -105,8 +74,6 @@ def box(
         return BoxedFloat(obj)
     elif type(obj) == str:
         return BoxedStr(obj)
-    elif _NUMPY_AVAILABLE and type(obj) == ndarray:
-        return BoxedNDArray(obj)
     elif type(obj) == datetime.datetime:
         return BoxedDatetime.fromtimestamp(obj.timestamp(), tz=datetime.timezone.utc)
     elif type(obj) == datetime.timedelta:
@@ -116,9 +83,8 @@ def box(
 
 def unbox(
     obj: T,
-) -> T | int | float | str | ndarray | datetime.datetime | datetime.timedelta:
-    """
-    Unbox an object to get the underlying value.
+) -> T | int | float | str | datetime.datetime | datetime.timedelta:
+    """Unbox an object to get the underlying value.
 
     Args:
         obj: The object to unbox.
@@ -140,8 +106,6 @@ def unbox(
         return float(obj)
     elif type(obj) == BoxedStr:
         return str(obj)
-    elif _NUMPY_AVAILABLE and type(obj) == BoxedNDArray:
-        return array(obj)
     elif type(obj) == BoxedDatetime:
         return datetime.datetime.fromtimestamp(obj.timestamp())
     elif type(obj) == BoxedTimedelta:
