@@ -65,6 +65,9 @@ class Call:
     deleted_at: datetime.datetime | None = None
     thread_id: str | None = None
     turn_id: str | None = None
+    wb_run_id: str | None = None
+    wb_run_step: int | None = None
+    wb_run_step_end: int | None = None
 
     # These are the live children during logging
     _children: list[Call] = dataclasses.field(default_factory=list)
@@ -414,6 +417,9 @@ def make_client_call(
         deleted_at=server_call.deleted_at,
         thread_id=server_call.thread_id,
         turn_id=server_call.turn_id,
+        wb_run_id=server_call.wb_run_id,
+        wb_run_step=server_call.wb_run_step,
+        wb_run_step_end=server_call.wb_run_step_end,
     )
     if isinstance(call.attributes, AttributesDict):
         call.attributes.freeze()
