@@ -944,6 +944,10 @@ class WeaveClient:
             output_json = to_json(
                 maybe_redacted_output_as_refs, project_id, self, use_dictify=False
             )
+
+            # Capture wb_run_step_end at call end time
+            current_wb_run_step_end = safe_current_wb_run_step()
+
             call_end_req = CallEndReq(
                 end=EndedCallSchemaForInsert(
                     project_id=project_id,
@@ -952,6 +956,7 @@ class WeaveClient:
                     output=output_json,
                     summary=merged_summary,
                     exception=exception_str,
+                    wb_run_step_end=current_wb_run_step_end,
                 )
             )
             bytes_size = len(call_end_req.model_dump_json())
