@@ -1039,6 +1039,7 @@ ALLOWED_CALL_FIELDS = {
     "wb_user_id": CallsMergedAggField(field="wb_user_id", agg_fn="any"),
     "wb_run_id": CallsMergedAggField(field="wb_run_id", agg_fn="any"),
     "wb_run_step": CallsMergedAggField(field="wb_run_step", agg_fn="any"),
+    "wb_run_step_end": CallsMergedAggField(field="wb_run_step_end", agg_fn="any"),
     "deleted_at": CallsMergedAggField(field="deleted_at", agg_fn="any"),
     "display_name": CallsMergedAggField(field="display_name", agg_fn="argMaxMerge"),
     "storage_size_bytes": AggFieldWithTableOverrides(
@@ -1618,7 +1619,90 @@ def process_calls_filter_to_conditions(
     return conditions
 
 
-def optimized_project_contains_call_query(
+######### STATS QUERY HANDLING ##########
+
+
+def build_calls_stats_query(
+    req: tsi.CallsQueryStatsReq,
+    param_builder: ParamBuilder,
+) -> tuple[str, KeysView[str]]:
+    """Build a stats query for calls, automatically using optimized queries when possible.
+
+    This function handles both optimized special-case queries and the general case.
+    Returns a tuple of (query_sql, column_names).
+
+    Args:
+        req: The stats query request
+        param_builder: Parameter builder for query parameterization
+
+    Returns:
+        Tuple of (SQL query string, column names in the result)
+    """
+    aggregated_columns = {"count": "count()"}
+
+    # Try optimized special case queries first
+    if opt_query := _try_optimized_stats_query(req, param_builder):
+        return (opt_query, aggregated_columns.keys())
+
+    # Fall back to general query builder
+    cq = CallsQuery(
+        project_id=req.project_id,
+        include_total_storage_size=req.include_total_storage_size or False,
+    )
+
+    cq.add_field("id")
+    if req.filter is not None:
+        cq.set_hardcoded_filter(HardCodedFilter(filter=req.filter))
+    if req.query is not None:
+        cq.add_condition(req.query.expr_)
+    if req.limit is not None:
+        cq.set_limit(req.limit)
+    if req.expand_columns is not None:
+        cq.set_expand_columns(req.expand_columns)
+
+    if req.include_total_storage_size:
+        aggregated_columns["total_storage_size_bytes"] = (
+            "sum(coalesce(total_storage_size_bytes, 0))"
+        )
+        cq.add_field("total_storage_size_bytes")
+
+    inner_query = cq.as_sql(param_builder)
+    calls_query_sql = f"SELECT {', '.join(aggregated_columns[k] for k in aggregated_columns)} FROM ({inner_query})"
+
+    return (calls_query_sql, aggregated_columns.keys())
+
+
+def _try_optimized_stats_query(
+    req: tsi.CallsQueryStatsReq, param_builder: ParamBuilder
+) -> Optional[str]:
+    """Try to match request to an optimized special-case query.
+
+    Returns optimized query string if a pattern matches, None otherwise.
+    Add new patterns here for common hot-path queries.
+    """
+    # Pattern 1: Simple existence check (limit=1, no filters)
+    if (
+        req.limit == 1
+        and req.filter is None
+        and req.query is None
+        and not req.include_total_storage_size
+    ):
+        return _optimized_project_contains_call_query(req.project_id, param_builder)
+
+    # Pattern 2: Query with wb_run_id check (limit=1, query present, minimal filter)
+    # Covers common case: checking for runs with wb_run_id not null
+    if (
+        req.limit == 1
+        and req.query is not None
+        and not req.include_total_storage_size
+        and _is_minimal_filter(req.filter)
+    ):
+        return _optimized_wb_run_id_not_null_query(req.project_id, param_builder)
+
+    return None
+
+
+def _optimized_project_contains_call_query(
     project_id: str,
     param_builder: ParamBuilder,
 ) -> str:
@@ -1638,33 +1722,38 @@ def optimized_project_contains_call_query(
     )
 
 
-def build_calls_query_stats_query(
-    req: tsi.CallsQueryStatsReq,
+def _optimized_wb_run_id_not_null_query(
+    project_id: str,
     param_builder: ParamBuilder,
-) -> tuple[str, KeysView[str]]:
-    cq = CallsQuery(
-        project_id=req.project_id,
-        include_total_storage_size=req.include_total_storage_size,
-    )
+) -> str:
+    """Optimized query for checking existence of calls with wb_run_id not null.
 
-    cq.add_field("id")
-    if req.filter is not None:
-        cq.set_hardcoded_filter(HardCodedFilter(filter=req.filter))
-    if req.query is not None:
-        cq.add_condition(req.query.expr_)
-    if req.limit is not None:
-        cq.set_limit(req.limit)
-    if req.expand_columns is not None:
-        cq.set_expand_columns(req.expand_columns)
-
-    aggregated_columns = {"count": "count()"}
-    if req.include_total_storage_size:
-        aggregated_columns["total_storage_size_bytes"] = (
-            "sum(coalesce(total_storage_size_bytes, 0))"
+    Uses WHERE clause instead of HAVING to avoid expensive aggregation.
+    """
+    project_id_param = param_builder.add_param(project_id)
+    return f"""
+        SELECT count() FROM (
+            SELECT calls_merged.id AS id
+            FROM calls_merged
+            WHERE calls_merged.project_id = {param_slot(project_id_param, "String")}
+                AND calls_merged.wb_run_id IS NOT NULL
+                AND calls_merged.deleted_at IS NULL
+            LIMIT 1
         )
-        cq.add_field("total_storage_size_bytes")
+    """
 
-    inner_query = cq.as_sql(param_builder)
-    calls_query_sql = f"SELECT {', '.join(aggregated_columns[k] for k in aggregated_columns)} FROM ({inner_query})"
 
-    return (calls_query_sql, aggregated_columns.keys())
+def _is_minimal_filter(filter: Optional[tsi.CallsFilter]) -> bool:
+    """Check if filter has no specific filtering criteria set."""
+    if filter is None:
+        return True
+    return (
+        filter.wb_run_ids is None
+        and filter.op_names is None
+        and filter.call_ids is None
+        and filter.trace_ids is None
+        and filter.parent_ids is None
+        and filter.trace_roots_only is None
+        and filter.input_refs is None
+        and filter.output_refs is None
+    )
