@@ -16,6 +16,7 @@ from opentelemetry.proto.collector.trace.v1.trace_service_pb2 import (
 from weave.trace_server import refs_internal as ri
 from weave.trace_server import trace_server_interface as tsi
 from weave.trace_server.errors import (
+    InvalidRequest,
     NotFoundError,
     ObjectDeletedError,
 )
@@ -31,7 +32,8 @@ from weave.trace_server.ids import generate_id
 from weave.trace_server.interface import query as tsi_query
 from weave.trace_server.methods.evaluation_status import evaluation_status
 from weave.trace_server.object_class_util import process_incoming_object_val
-from weave.trace_server.opentelemetry.python_spans import ResourceSpans
+from weave.trace_server.opentelemetry.helpers import AttributePathConflictError
+from weave.trace_server.opentelemetry.python_spans import Resource, Span
 from weave.trace_server.orm import quote_json_path
 from weave.trace_server.threads_query_builder import make_threads_query_sqlite
 from weave.trace_server.trace_server_common import (
@@ -117,6 +119,7 @@ class SqliteTraceServer(tsi.TraceServerInterface):
                 wb_user_id TEXT,
                 wb_run_id TEXT,
                 wb_run_step INTEGER,
+                wb_run_step_end INTEGER,
                 deleted_at TEXT,
                 display_name TEXT
             )
@@ -253,7 +256,8 @@ class SqliteTraceServer(tsi.TraceServerInterface):
                     exception = ?,
                     output = ?,
                     output_refs = ?,
-                    summary = ?
+                    summary = ?,
+                    wb_run_step_end = ?
                 WHERE id = ?""",
                 (
                     req.end.ended_at.isoformat(),
@@ -263,6 +267,7 @@ class SqliteTraceServer(tsi.TraceServerInterface):
                         extract_refs_from_values(list(parsable_output.values()))
                     ),
                     json.dumps(req.end.summary),
+                    req.end.wb_run_step_end,
                     req.end.id,
                 ),
             )
@@ -369,8 +374,14 @@ class SqliteTraceServer(tsi.TraceServerInterface):
                     cond = f"(NOT ({operand_part}))"
                 elif isinstance(operation, tsi_query.EqOperation):
                     lhs_part = process_operand(operation.eq_[0])
-                    rhs_part = process_operand(operation.eq_[1])
-                    cond = f"({lhs_part} = {rhs_part})"
+                    if (
+                        isinstance(operation.eq_[1], tsi_query.LiteralOperation)
+                        and operation.eq_[1].literal_ is None
+                    ):
+                        cond = f"({lhs_part} IS NULL)"
+                    else:
+                        rhs_part = process_operand(operation.eq_[1])
+                        cond = f"({lhs_part} = {rhs_part})"
                 elif isinstance(operation, tsi_query.GtOperation):
                     lhs_part = process_operand(operation.gt_[0])
                     rhs_part = process_operand(operation.gt_[1])
@@ -909,6 +920,14 @@ class SqliteTraceServer(tsi.TraceServerInterface):
                 placeholders = ",".join(["?" for _ in req.filter.base_object_classes])
                 conds.append(f"base_object_class IN ({placeholders})")
                 parameters["base_object_classes"] = req.filter.base_object_classes
+            if req.filter.exclude_base_object_classes:
+                placeholders = ",".join(
+                    ["?" for _ in req.filter.exclude_base_object_classes]
+                )
+                conds.append(f"base_object_class NOT IN ({placeholders})")
+                parameters["exclude_base_object_classes"] = (
+                    req.filter.exclude_base_object_classes
+                )
             if req.filter.leaf_object_classes:
                 placeholders = ",".join(["?" for _ in req.filter.leaf_object_classes])
                 conds.append(f"leaf_object_class IN ({placeholders})")
@@ -1130,9 +1149,25 @@ class SqliteTraceServer(tsi.TraceServerInterface):
             for sort in req.sort_by:
                 field = sort.field
                 direction = sort.direction.upper()
+
+                # Validate sort field to prevent empty JSON paths
+                if not field or not field.strip():
+                    raise InvalidRequest("Sort field cannot be empty")
+
+                # Check for invalid dot patterns that would create malformed JSON paths
+                if field.startswith(".") or field.endswith(".") or ".." in field:
+                    raise InvalidRequest(
+                        f"Invalid sort field '{field}': field names cannot start/end with dots or contain consecutive dots"
+                    )
+
                 if "." in field:
                     # Handle nested fields
                     parts = field.split(".")
+                    # Additional validation: ensure no empty path components
+                    if any(not component.strip() for component in parts):
+                        raise InvalidRequest(
+                            f"Invalid sort field '{field}': field path components cannot be empty"
+                        )
                     field = f"json_extract(tr.val, '$.{'.'.join(parts)}')"
                 else:
                     field = f"json_extract(tr.val, '$.{field}')"
@@ -1453,32 +1488,64 @@ class SqliteTraceServer(tsi.TraceServerInterface):
         response = self.completions_create(req)
         yield {"response": response.response, "weave_call_id": response.weave_call_id}
 
+    def image_create(
+        self, req: tsi.ImageGenerationCreateReq
+    ) -> tsi.ImageGenerationCreateRes:
+        # TODO: This is not implemented for the sqlite trace server
+        # Currently, this will only be called from the weave file, so we return an empty dict for now
+        return tsi.ImageGenerationCreateRes(response={})
+
     def otel_export(self, req: tsi.OtelExportReq) -> tsi.OtelExportRes:
         if not isinstance(req.traces, ExportTraceServiceRequest):
             raise TypeError(
                 "Expected traces as ExportTraceServiceRequest, got {type(req.traces)}"
             )
 
-        traces_data = [
-            ResourceSpans.from_proto(span) for span in req.traces.resource_spans
-        ]
-
-        calls = []
-        for resource_spans in traces_data:
-            for scope_spans in resource_spans.scope_spans:
-                for span in scope_spans.spans:
-                    start_call, end_call = span.to_call(req.project_id)
-                    calls.extend(
-                        [
-                            {
-                                "mode": "start",
-                                "req": tsi.CallStartReq(start=start_call),
-                            },
-                            {"mode": "end", "req": tsi.CallEndReq(end=end_call)},
-                        ]
-                    )
+        calls: list[dict[str, object]] = []
+        rejected_spans = 0
+        error_messages: list[str] = []
+        for proto_resource_spans in req.traces.resource_spans:
+            resource = Resource.from_proto(proto_resource_spans.resource)
+            for proto_scope_spans in proto_resource_spans.scope_spans:
+                for proto_span in proto_scope_spans.spans:
+                    try:
+                        span = Span.from_proto(proto_span, resource)
+                        start_call, end_call = span.to_call(req.project_id)
+                        calls.extend(
+                            [
+                                {
+                                    "mode": "start",
+                                    "req": tsi.CallStartReq(start=start_call),
+                                },
+                                {"mode": "end", "req": tsi.CallEndReq(end=end_call)},
+                            ]
+                        )
+                    except AttributePathConflictError as e:
+                        rejected_spans += 1
+                        try:
+                            trace_id = proto_span.trace_id.hex()
+                            span_id = proto_span.span_id.hex()
+                            name = getattr(proto_span, "name", "")
+                        except Exception:
+                            trace_id = ""
+                            span_id = ""
+                            name = ""
+                        span_ident = (
+                            f"name='{name}' trace_id='{trace_id}' span_id='{span_id}'"
+                        )
+                        error_messages.append(f"Rejected span ({span_ident}): {e!s}")
         res = self.call_start_batch(tsi.CallCreateBatchReq(batch=calls))
-        # Return the empty ExportTraceServiceResponse as per the OTLP spec
+        # Return spec-compliant response; include partial_success if needed
+        if rejected_spans > 0:
+            return tsi.OtelExportRes(
+                partial_success=tsi.ExportTracePartialSuccess(
+                    rejected_spans=rejected_spans,
+                    error_message=(
+                        "; ".join(error_messages[:20])
+                        + ("; ..." if len(error_messages) > 20 else "")
+                    ),
+                )
+            )
         return tsi.OtelExportRes()
 
     def project_stats(self, req: tsi.ProjectStatsReq) -> tsi.ProjectStatsRes:
