@@ -1,10 +1,10 @@
+from weave.type_handlers import Video
 from weave.type_handlers.Audio import audio
 from weave.type_handlers.Content import content
 from weave.type_handlers.DateTime import datetime
 from weave.type_handlers.File import file
 from weave.type_handlers.Image import image
 from weave.type_handlers.Markdown import markdown
-from weave.type_handlers.Video import video
 
 file.register()
 content.register()
@@ -12,4 +12,5 @@ image.register()
 audio.register()
 datetime.register()
 markdown.register()
-video.register()
+
+Video.install_hook()
